@@ -90,12 +90,26 @@ static void i830_sdvo_write_sdvox(xf86OutputPtr output, CARD32 val)
     I830OutputPrivatePtr    intel_output = output->driver_private;
     struct i830_sdvo_priv   *dev_priv = intel_output->dev_priv;
     I830Ptr		    pI830 = I830PTR(pScrn);
+    CARD32		    bval = val, cval = val;
+    int			    i;
 
-    if (dev_priv->output_device == SDVOC)
-	OUTREG(SDVOB, INREG(SDVOB));
-    OUTREG(dev_priv->output_device, val);
     if (dev_priv->output_device == SDVOB)
-	OUTREG(SDVOC, INREG(SDVOC));
+	cval = INREG(SDVOC);
+    else
+	bval = INREG(SDVOB);
+    
+    /*
+     * Write the registers twice for luck. Sometimes,
+     * writing them only once doesn't appear to 'stick'.
+     * The BIOS does this too. Yay, magic
+     */
+    for (i = 0; i < 2; i++)
+    {
+	OUTREG(SDVOB, bval);
+	POSTING_READ(SDVOB);
+	OUTREG(SDVOC, cval);
+	POSTING_READ(SDVOC);
+    }
 }
 
 /** Read a single byte from the given address on the SDVO device. */
@@ -200,6 +214,7 @@ static I2CSlaveAddr slaveAddr;
 static void
 i830_sdvo_write_cmd(xf86OutputPtr output, CARD8 cmd, void *args, int args_len)
 {
+    I830Ptr pI830 = I830PTR(output->scrn);
     I830OutputPrivatePtr    intel_output = output->driver_private;
     struct i830_sdvo_priv   *dev_priv = intel_output->dev_priv;
     int			    i;
@@ -208,20 +223,25 @@ i830_sdvo_write_cmd(xf86OutputPtr output, CARD8 cmd, void *args, int args_len)
 	ErrorF ("Mismatch slave addr %x != %x\n", slaveAddr, dev_priv->d.SlaveAddr);
 
     /* Write the SDVO command logging */
-    xf86DrvMsg(intel_output->pI2CBus->scrnIndex, X_INFO, "%s: W: %02X ", SDVO_NAME(dev_priv), cmd);
-    for (i = 0; i < args_len; i++)
-	LogWrite(1, "%02X ", ((CARD8 *)args)[i]);
-    for (; i < 8; i++)
-	LogWrite(1, "   ");
-    for (i = 0; i < sizeof(sdvo_cmd_names) / sizeof(sdvo_cmd_names[0]); i++) {
-	if (cmd == sdvo_cmd_names[i].cmd) {
-	    LogWrite(1, "(%s)", sdvo_cmd_names[i].name);
-	    break;
+    if (pI830->debug_modes) {
+	xf86DrvMsg(intel_output->pI2CBus->scrnIndex, X_INFO, "%s: W: %02X ",
+		   SDVO_NAME(dev_priv), cmd);
+	for (i = 0; i < args_len; i++)
+	    LogWrite(1, "%02X ", ((CARD8 *)args)[i]);
+	for (; i < 8; i++)
+	    LogWrite(1, "   ");
+	for (i = 0; i < sizeof(sdvo_cmd_names) / sizeof(sdvo_cmd_names[0]);
+	     i++)
+	{
+	    if (cmd == sdvo_cmd_names[i].cmd) {
+		LogWrite(1, "(%s)", sdvo_cmd_names[i].name);
+		break;
+	    }
 	}
+	if (i == sizeof(sdvo_cmd_names) / sizeof(sdvo_cmd_names[0]))
+	    LogWrite(1, "(%02X)", cmd);
+	LogWrite(1, "\n");
     }
-    if (i == sizeof(sdvo_cmd_names) / sizeof(sdvo_cmd_names[0]))
-	LogWrite(1, "(%02X)", cmd);
-    LogWrite(1, "\n");
 
     /* send the output regs */
     for (i = 0; i < args_len; i++) {
@@ -247,33 +267,43 @@ static const char *cmd_status_names[] = {
 static CARD8
 i830_sdvo_read_response(xf86OutputPtr output, void *response, int response_len)
 {
+    I830Ptr pI830 = I830PTR(output->scrn);
     I830OutputPrivatePtr    intel_output = output->driver_private;
     int			    i;
     CARD8		    status;
+    CARD8		    retry = 50;
 
-    /* Read the command response */
-    for (i = 0; i < response_len; i++) {
-	i830_sdvo_read_byte(output, SDVO_I2C_RETURN_0 + i,
+    while (retry--) {
+    	/* Read the command response */
+    	for (i = 0; i < response_len; i++) {
+	    i830_sdvo_read_byte(output, SDVO_I2C_RETURN_0 + i,
 			    &((CARD8 *)response)[i]);
-    }
+    	}
 
-    /* Read the return status */
-    i830_sdvo_read_byte(output, SDVO_I2C_CMD_STATUS, &status);
+    	/* Read the return status */
+    	i830_sdvo_read_byte(output, SDVO_I2C_CMD_STATUS, &status);
 
-    /* Write the SDVO command logging */
-    xf86DrvMsg(intel_output->pI2CBus->scrnIndex, X_INFO,
-	       "%s: R: ", SDVO_NAME(SDVO_PRIV(intel_output)));
-    for (i = 0; i < response_len; i++)
-	LogWrite(1, "%02X ", ((CARD8 *)response)[i]);
-    for (; i < 8; i++)
-	LogWrite(1, "   ");
-    if (status <= SDVO_CMD_STATUS_SCALING_NOT_SUPP)
-    {
-	LogWrite(1, "(%s)", cmd_status_names[status]);
-    } else {
-	LogWrite(1, "(??? %d)", status);
+    	/* Write the SDVO command logging */
+    	if (pI830->debug_modes) {
+	    xf86DrvMsg(intel_output->pI2CBus->scrnIndex, X_INFO,
+		   "%s: R: ", SDVO_NAME(SDVO_PRIV(intel_output)));
+	    for (i = 0; i < response_len; i++)
+	    	LogWrite(1, "%02X ", ((CARD8 *)response)[i]);
+	    for (; i < 8; i++)
+	    	LogWrite(1, "   ");
+	    if (status <= SDVO_CMD_STATUS_SCALING_NOT_SUPP) {
+	    	LogWrite(1, "(%s)", cmd_status_names[status]);
+	    } else {
+	    	LogWrite(1, "(??? %d)", status);
+	    }
+	    LogWrite(1, "\n");
+    	}
+
+	if (status != SDVO_CMD_STATUS_PENDING)
+	    return status;
+
+        intel_output->pI2CBus->I2CUDelay(intel_output->pI2CBus, 50);
     }
-    LogWrite(1, "\n");
 
     return status;
 }
@@ -697,16 +727,20 @@ i830_sdvo_mode_set(xf86OutputPtr output, DisplayModePtr mode,
     }
 
     /* Set the SDVO control regs. */
-    sdvox = INREG(dev_priv->output_device);
-    switch (dev_priv->output_device) {
-    case SDVOB:
-	sdvox &= SDVOB_PRESERVE_MASK;
-	break;
-    case SDVOC:
-	sdvox &= SDVOC_PRESERVE_MASK;
-	break;
+    if (IS_I965GM(pI830)) {
+	sdvox = SDVO_BORDER_ENABLE;
+    } else {
+	sdvox = INREG(dev_priv->output_device);
+	switch (dev_priv->output_device) {
+	case SDVOB:
+	    sdvox &= SDVOB_PRESERVE_MASK;
+	    break;
+	case SDVOC:
+	    sdvox &= SDVOC_PRESERVE_MASK;
+	    break;
+	}
+	sdvox |= (9 << 19) | SDVO_BORDER_ENABLE;
     }
-    sdvox |= (9 << 19) | SDVO_BORDER_ENABLE;
     if (intel_crtc->pipe == 1)
 	sdvox |= SDVO_PIPE_B_SELECT;
 
@@ -740,7 +774,6 @@ i830_sdvo_dpms(xf86OutputPtr output, int mode)
 	    temp = INREG(dev_priv->output_device);
 	    if ((temp & SDVO_ENABLE) != 0) {
 		i830_sdvo_write_sdvox(output, temp & ~SDVO_ENABLE);
-		POSTING_READ(dev_priv->output_device);
 	    }
 	}
     } else {
@@ -750,19 +783,7 @@ i830_sdvo_dpms(xf86OutputPtr output, int mode)
 
 	temp = INREG(dev_priv->output_device);
 	if ((temp & SDVO_ENABLE) == 0)
-	{
 	    i830_sdvo_write_sdvox(output, temp | SDVO_ENABLE);
-	    POSTING_READ(dev_priv->output_device);
-#if 0
-	    /* Do it again!  If we remove this below register write, or the
-	     * exact same one 2 lines up, the mac mini SDVO output doesn't
-	     * turn on.
-	     */
-	    i830_sdvo_write_sdvox(output, INREG(dev_priv->output_device) |
-				  SDVO_ENABLE);
-	    POSTING_READ(dev_priv->output_device);
-#endif
-	}
 	for (i = 0; i < 2; i++)
 	    i830WaitForVblank(pScrn);
 
